@@ -24,18 +24,19 @@
 #define INCIDENCEEDITOR_INDIVIDUALMAILDIALOG_H
 
 #include <KCalCore/Attendee>
-#include <KDialog>
+#include <QDialog>
 
 #include <QComboBox>
+#include <QDialogButtonBox>
+
+class KGuiItem;
 
 class TestIndividualMailDialog;
 
-namespace IncidenceEditorNG
-{
-
+namespace IncidenceEditorNG {
 // Shows a dialog with a question and the option to select which attendee should get the mail or to open a composer for him.
 // Used to get individual mails for attendees of an event.
-class IndividualMailDialog : public KDialog
+class IndividualMailDialog : public QDialog
 {
     Q_OBJECT
     friend class ::TestIndividualMailDialog;
@@ -45,17 +46,22 @@ public:
         NoUpdate,       /**< do not send mail to attendee */
         Edit            /**< open composer for attendee */
     };
-    explicit IndividualMailDialog(const QString &question, const KCalCore::Attendee::List &attendees,
-                                  const KGuiItem &buttonYes, const KGuiItem &buttonNo, QWidget *parent = nullptr);
+    explicit IndividualMailDialog(const QString &question,
+                                  const KCalCore::Attendee::List &attendees,
+                                  const KGuiItem &buttonYes, const KGuiItem &buttonNo,
+                                  QWidget *parent = nullptr);
     virtual ~IndividualMailDialog();
 
     KCalCore::Attendee::List editAttendees() const;
     KCalCore::Attendee::List updateAttendees() const;
 
 private:
-    QHash<KCalCore::Attendee::Ptr, QComboBox *> mAttendeeDecision;
-};
+    void updateButtonState();
 
+    QHash<KCalCore::Attendee::Ptr, QComboBox *> mAttendeeDecision;
+    QDialogButtonBox *m_buttons;
+    QWidget *m_detailsWidget;
+};
 }
 
 #endif
